@@ -8,7 +8,7 @@ use vars qw(@ISA $VERSION %CIPHERS);
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '0.53_01';
+$VERSION = '0.53_02';
 
 bootstrap Crypt::SSLeay $VERSION;
 
@@ -78,8 +78,8 @@ Crypt::SSLeay - OpenSSL glue that provides LWP https support
 
 =head1 DESCRIPTION
 
-This document describes C<Crypt::SSLeay> version 0.53_01, released
-2007-01-24.
+This document describes C<Crypt::SSLeay> version 0.53_02, released
+2007-01-29.
 
 This perl module provides support for the https protocol under LWP,
 to allow an C<LWP::UserAgent> object to perform GET, HEAD and POST
@@ -96,11 +96,7 @@ This distribution also makes following deprecated modules available:
   Crypt::SSLeay::X509
 
 Work on Crypt::SSLeay has been continued only to provide https
-support for the LWP (libwww-perl) libraries. People wishing to
-access the OpenSSL API directly from Perl are advised to look at
-the C<Net::SSLeay> module.
-
-  http://search.cpan.org/dist/Net_SSLeay.pm/
+support for the LWP (libwww-perl) libraries.
 
 =head1 INSTALL
 
@@ -163,7 +159,7 @@ LWP::UserAgent and Crypt::SSLeay have their own versions of
 proxy support. Please read these sections to see which one
 may be right for you.
 
-=head2 LWP::UserAgent Proxy Support
+=head2 LWP::UserAgent proxy support
 
 LWP::UserAgent has its own methods of proxying which may work for
 you and is likely to be incompatible with Crypt::SSLeay proxy support.
@@ -182,7 +178,7 @@ some proxies would expect, so this may not work with other
 proxy servers than mod_proxy.  The CONNECT method is used
 by Crypt::SSLeay's internal proxy support.
 
-=head2 Crypt::SSLeay Proxy Support
+=head2 Crypt::SSLeay proxy support
 
 For native Crypt::SSLeay proxy support of https requests,
 you need to set an environment variable HTTPS_PROXY to your 
@@ -205,7 +201,7 @@ this way:
   $ENV{HTTPS_PROXY_PASSWORD} = 'password';  
 
 For an example of LWP scripting with Crypt::SSLeay native proxy
-support, please look at the F<lwp-ssl-test> script in the 
+support, please look at the F<eg/lwp-ssl-test> script in the 
 Crypt::SSLeay distribution.
 
 =head1 CLIENT CERTIFICATE SUPPORT
@@ -216,10 +212,10 @@ private key files may be used like this:
   $ENV{HTTPS_CERT_FILE} = 'certs/notacacert.pem';
   $ENV{HTTPS_KEY_FILE}  = 'certs/notacakeynopass.pem';
 
-You may test your files with the F<eg/net_ssl_test> program,
+You may test your files with the F<eg/net-ssl-test> program,
 bundled with the distribution, by issuing a command like:
 
-  perl eg/net_ssl_test -cert=certs/notacacert.pem \
+  perl eg/net-ssl-test -cert=certs/notacacert.pem \
 	-key=certs/notacakeynopass.pem -d GET $HOST_NAME
 
 Additionally, if you would like to tell the client where
@@ -229,7 +225,7 @@ the CA file is, you may set these.
   $ENV{HTTPS_CA_DIR}  = "some_dir";
 
 There is no sample CA cert file at this time for testing,
-but you may configure F<eg/net_ssl_test> to use your CA cert
+but you may configure F<eg/net-ssl-test> to use your CA cert
 with the -CAfile option. (TODO: then what is the ./certs
 directory in the distribution?)
 
@@ -278,102 +274,41 @@ so that a SSL v3 connection is tried first. At this time
 only a SSL v2 connection will be tried after this, as the 
 connection attempt order remains unchanged by this setting.
 
-=head1 BUILD NOTES
+=head1 ACKNOWLEDGEMENTS
 
-=head2 Win32, WinNT, Win2000, can't build
+Many thanks to Gisle Aas for writing this module and many others
+including libwww, for perl. The web will never be the same :)
 
-If you cannot get it to build on your windows box, try 
-ActiveState perl, at least their builds 522 & 618 are
-known to have a ppm install of Crypt::SSLeay available.
-Please see http://www.activestate.com for more info.
+Ben Laurie deserves kudos for his excellent patches for better error
+handling, SSL information inspection, and random seeding.
 
-=head2 AIX 4.3.2 - Symbol Error: __umoddi3 : referenced symbol not found
+Thanks to Dongqiang Bai for host name resolution fix when using a
+proxy.
 
-The __umoddi3 problem applies here as well when compiling with gcc.
+Thanks to Stuart Horner of Core Communications, Inc. who found the
+need for building --shared OpenSSL libraries.
 
-Alternative solution:
-In F<Makefile.PL>, prepend C<-L>/usr/local/<path to your gcc lib>/<version>
-to the $LIBS value. Add after line 82:
+Thanks to Pavel Hlavnicka for a patch for freeing memory when using
+a pkcs12 file, and for inspiring more robust read() behavior.
 
- $LIBS = '-L' . dirname(`gcc -print-libgcc-file-name`) . ' ' . $LIBS;
-
-=head2 Solaris x86 - Symbol Error: __umoddi3 : referenced symbol not found
-
- Problem:
-
-On Solaris x86, the default PERL configuration, and preferred, is to use
-the ld linker that comes with the OS, not gcc.  Unfortunately during the 
-OpenSSL build process, gcc generates in libcrypto.a, from bn_word.c,
-the undefined symbol __umoddi3, which is supposed to be later resolved
-by gcc from libgcc.a
-
-The system ld linker does not know about libgcc.a by default, so 
-when building Crypt::SSLeay, there is a linker error for __umoddi3
-
- Solution:
-
-The fix for this symlink your libgcc.a to some standard directory
-like /usr/local/lib, so that the system linker, ld, can find
-it when building Crypt::SSLeay.  
-
-=head2 FreeBSD 2.x.x / Solaris - ... des.h:96 #error _ is defined ...
-
-If you encounter this error: "...des.h:96: #error _ is
-defined, but some strange definition the DES library cannot handle
-that...," then you need to edit the des.h file and comment out the 
-"#error" line.
-
-Its looks like this error might be common to other operating
-systems, and that occurs with OpenSSL 0.9.3.  Upgrades to
-0.9.4 seem to fix this problem.
-
-=head2 SunOS 4.1.4, Perl 5.004_04 - ld.so: Undefined symbol: _CRYPT_mem_ctrl
-
-Problems: (initial build was fine, but execution of Perl scripts had problems)
-
-Got a message "ld.so: Undefined symbol: _CRYPT_mem_ctrl"
-solution:  In the Makefile, comment out the line with
-"-fpic"  (also try changing to "-fPIC", and this works
-also, not sure if one is preferred).
-
-=head1 NOTES
-
-Many thanks to Gisle Aas for the original writing of 
-this module and many others including libwww for perl.  
-The web will never be the same :)
-
-Ben Laurie deserves kudos for his excellent patches
-for better error handling, SSL information inspection,
-and random seeding.
-
-Thanks to Dongqiang Bai for host name resolution fix when
-using a proxy.
-
-Thanks to Stuart Horner of Core Communications, Inc. who found
-the need for building --shared OpenSSL libraries.
-
-Thanks to Pavel Hlavnicka for a patch for freeing memory when
-using a pkcs12 file, and for inspiring more robust read() behavior.
-
-James Woodyatt is a champ for finding a ridiculous memory
-leak that has been the bane of many a Crypt::SSLeay user.
+James Woodyatt is a champ for finding a ridiculous memory leak that
+has been the bane of many a Crypt::SSLeay user.
 
 Thanks to Bryan Hart for his patch adding proxy support,
 and thanks to Tobias Manthey for submitting another approach.
 
 Thanks to Alex Rhomberg for Alpha linux ccc patch.
 
-Thanks to Tobias Manthey for his patches for client 
-certificate support.
-
-Thanks to Daisuke Kuroda for adding PKCS12 certificate
+Thanks to Tobias Manthey for his patches for client certificate
 support.
 
-Thanks to Gamid Isayev for CA cert support and 
-insights into error messaging.
+Thanks to Daisuke Kuroda for adding PKCS12 certificate support.
 
-Thanks to Jeff Long for working through a tricky CA
-cert SSLClientVerify issue.
+Thanks to Gamid Isayev for CA cert support and insights into error
+messaging.
+
+Thanks to Jeff Long for working through a tricky CA cert SSLClientVerify
+issue.
 
 Thanks to Chip Turner for patch to build under perl 5.8.0.
 
@@ -383,6 +318,22 @@ module.
 Thanks to Jeff Lavallee for help with alarms on read failures (CPAN
 bug #12444).
 
+=head1 SEE ALSO
+
+=over 4
+
+=item Net::SSLeay
+
+A module that offers access to the OpenSSL API directly from Perl.
+
+  http://search.cpan.org/dist/Net_SSLeay.pm/
+
+=item http://www.openssl.org/related/binaries.html
+
+Pointers on where to find OpenSSL binary packages (Windows).
+
+=back
+
 =head1 SUPPORT
 
 For use of Crypt::SSLeay & Net::SSL with perl's LWP, please
